@@ -129,7 +129,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -145,15 +145,15 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigateway
-import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import aws_cdk.aws_logs
-import constructs
+import aws_cdk.aws_apigateway as _aws_cdk_aws_apigateway_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ApiGatewayToLambda(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambda",
 ):
@@ -163,13 +163,13 @@ class ApiGatewayToLambda(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         api_gateway_props: typing.Any = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -184,17 +184,7 @@ class ApiGatewayToLambda(
         :summary: Constructs a new instance of the ApiGatewayToLambda class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                api_gateway_props: typing.Any = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8cee3d89f313102b389deed0cd200d7ab2323cfe0ad8769e94f7167b7806bfaa)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToLambdaProps(
@@ -208,23 +198,25 @@ class ApiGatewayToLambda(
 
     @builtins.property
     @jsii.member(jsii_name="apiGateway")
-    def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
+    def api_gateway(self) -> _aws_cdk_aws_apigateway_ceddda9d.RestApi:
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.RestApi, jsii.get(self, "apiGateway"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
-    def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
+    def api_gateway_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
-    def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
+    def api_gateway_cloud_watch_role(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
 
 
 @jsii.data_type(
@@ -242,9 +234,9 @@ class ApiGatewayToLambdaProps:
         self,
         *,
         api_gateway_props: typing.Any = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''The properties for the ApiGatewayToLambda class.
 
@@ -254,24 +246,16 @@ class ApiGatewayToLambdaProps:
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if __debug__:
-            def stub(
-                *,
-                api_gateway_props: typing.Any = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9be9eacf3e580c106bf97e65962dc01354d2e8ce46fb5733931b1f0ec7f5a9ef)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
         if existing_lambda_obj is not None:
@@ -291,33 +275,37 @@ class ApiGatewayToLambdaProps:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used.
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -337,3 +325,25 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8cee3d89f313102b389deed0cd200d7ab2323cfe0ad8769e94f7167b7806bfaa(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    api_gateway_props: typing.Any = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9be9eacf3e580c106bf97e65962dc01354d2e8ce46fb5733931b1f0ec7f5a9ef(
+    *,
+    api_gateway_props: typing.Any = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
